@@ -17,7 +17,7 @@ def tokenize(seq):
     digit_seq = []
     for aa in seq:
         if aa not in AA_DICT:
-            print(f'Unknown amino acid letter \"{aa}\"')
+            # print(f'Unknown amino acid letter \"{aa}\"')
             return None
         digit_seq.append(AA_DICT[aa])
 
@@ -39,8 +39,9 @@ def mask_data(data, mask_prob, one_in_middle=False):
         bool_mask = np.random.rand(data.shape[0] * data.shape[1]) < mask_prob
         bool_mask = bool_mask.reshape(data.shape)
 
-    bool_mask[:, 0] = False
-    bool_mask[:, -1] = False
+    # TODO-WARNING: resolve this issue!
+    # bool_mask[:, 0] = False
+    # bool_mask[:, -1] = False
 
     to_replace = data[bool_mask]
 
@@ -124,11 +125,12 @@ def double_mask(src_file, seq_len, mask_prob_1, mask_prob_2, batch_size, use_mas
 if __name__ == '__main__':
     from pathlib import Path
 
-    ROOT = Path(r'C:\DATA\ML-Data\BioML\datasets\UniRef90')
+    ROOT = Path(r'C:\DATA\ML-Data\BioML\datasets\Prot2Vec_dataset_2022-06')
 
-    # ds_it = ds_iter(ROOT / 'refprot_random_taxfree.tsv', 64, 0.15, 1024, True)
-    ds_it = double_mask(ROOT / 'refprot_random_taxfree.tsv', 24, 0.15, 0.35, 32, False, 'full')
+    ds_it = ds_iter(ROOT / 'uniref90_tax-free_shuffled.tsv', 64, 0.15, 1024)
+    # ds_it = double_mask(ROOT / 'refprot_random_taxfree.tsv', 24, 0.15, 0.35, 32, False, 'full')
 
     for i in range(1000):
         a = next(ds_it)
+        a = np.argmax(a[0], axis=-1), np.argmax(a[1], axis=-1), a[2]
         print()
